@@ -1,26 +1,45 @@
+from __future__ import annotations
+
 import abc
 import asyncio
+import typing
 import unittest
-from typing import AsyncGenerator, Optional, Dict, Any, Union, List, Tuple
+from types import TracebackType
+from typing import AsyncGenerator, Optional, Dict, Any, Union, List, Tuple, Type
 
-from aiohttp import ClientSession, web
+from aiohttp import web
 from aiohttp.typedefs import LooseCookies
 
-from glQiwiApi import types
-from glQiwiApi.core.web_hooks.handler import HandlerManager
+from glQiwiApi.core.web_hooks.dispatcher import Dispatcher
 from glQiwiApi.types import Response
 
 
-class BaseStorage(abc.ABC):
+class SingletonABCMeta(abc.ABCMeta):
+    """
+    Abstract singleton metaclass, using for routers because in class methods
+    it's not possible to get the router object,
+    so we need singleton to get the same instances of routers
+
+    """
+    _instances: Dict[Any, Any] = {}
+
+    def __call__(cls, *args, **kwargs):
+        if cls not in cls._instances:
+            cls._instances[cls] = super(SingletonABCMeta, cls).__call__(
+                *args, **kwargs
+            )
+        return cls._instances[cls]
+
+
+T = typing.TypeVar("T")
+
+
+class BaseStorage(abc.ABC, typing.Generic[T]):
     """
     Абстрактный класс контроллера кэша
 
     """
 
-    @abc.abstractmethod
-    def get_current(self, key: str) -> Any:
-        raise NotImplementedError
-
     @abc.abstractmethod
     def clear(self, key: str, force: bool = False) -> Any:
         raise NotImplementedError
@@ -28,34 +47,30 @@ class BaseStorage(abc.ABC):
     def update_data(self, obj_to_cache: Any, key: Any) -> None:
         raise NotImplementedError
 
-    def validate(self, kwargs: Dict[str, Any]) -> None:
+    def validate(self, kwargs: Dict[str, Any]) -> bool:
         """ Should validate some data from cache """
 
 
-class AbstractPaymentWrapper(abc.ABC):
-    """
-    Abstract class for payment wrappers,
-    you can add a new one, using this class, and than,
-    just send a pull request to GitHub repository,
-    if it will be pretty and simple, our team
-    add it to the library in next release
+class AbstractRouter(metaclass=SingletonABCMeta):
+    """Abstract class-router for building urls"""
 
-    """
+    def __init__(self):
+        self.config = self.setup_config()
 
     @abc.abstractmethod
-    async def transactions(self, *args, **kwargs) -> None:
+    def setup_config(self) -> Any:
         raise NotImplementedError
 
-    @abc.abstractmethod
-    async def transaction_info(self, *args, **kwargs) -> None:
-        raise NotImplementedError
+    @staticmethod
+    def _format_url_kwargs(url_: str, **kwargs: Any) -> Optional[str]:
+        try:
+            return url_.format(**kwargs)
+        except KeyError:
+            raise RuntimeError("Bad kwargs for url build")
 
     @abc.abstractmethod
-    async def get_balance(self) -> None:
-        raise NotImplementedError
-
-    @abc.abstractmethod
-    async def account_info(self, *args, **kwargs) -> None:
+    def build_url(self, api_method: str, **kwargs: Any) -> str:
+        """Implementation of building url"""
         raise NotImplementedError
 
 
@@ -88,13 +103,10 @@ class AioTestCase(unittest.TestCase):
 class AbstractParser(abc.ABC):
     """ Abstract class of parser for send request to different API's"""
 
-    def __init__(self):
-        self.session: Optional[ClientSession] = None
-
     @abc.abstractmethod
-    async def _request(
+    async def _make_request(
             self,
-            url: Optional[str],
+            url: str,
             get_json: bool,
             method: str,
             set_timeout: bool,
@@ -110,7 +122,9 @@ class AbstractParser(abc.ABC):
                 Dict[str, Union[str, int, List[
                     Union[str, int]
                 ]]]
-            ]) -> Response:
+            ],
+            get_bytes: bool,
+            **kwargs) -> Response:
         raise NotImplementedError
 
     @abc.abstractmethod
@@ -123,21 +137,31 @@ class AbstractParser(abc.ABC):
         """ You can override it, but is must to return an AsyncGenerator """
         raise NotImplementedError
 
+    @abc.abstractmethod
+    async def close(self) -> None:  # pragma: no cover
+        """
+        Close client session
+        """
+        pass
+
     def raise_exception(
             self,
-            status_code: Union[str, int],
+            status_code: str,
             json_info: Optional[Dict[str, Any]] = None,
             message: Optional[str] = None
     ) -> None:
         """Метод для обработки исключений и лучшего логирования"""
 
-    def create_session(self, **kwargs) -> None:
-        """ Creating new session if old was close or it's None """
-        if self.session is None:
-            self.session = ClientSession(**kwargs)
-        elif isinstance(self.session, ClientSession):
-            if self.session.closed:
-                self.session = ClientSession(**kwargs)
+    async def __aenter__(self) -> AbstractParser:
+        return self
+
+    async def __aexit__(
+            self,
+            exc_type: Optional[Type[BaseException]],
+            exc_value: Optional[BaseException],
+            traceback: Optional[TracebackType],
+    ) -> None:
+        await self.close()
 
 
 class BaseWebHookView(web.View):
@@ -153,7 +177,8 @@ class BaseWebHookView(web.View):
     app_key_handler_manager: Optional[str] = None
     """app_key_handler_manager"""
 
-    def _check_ip(self, ip_address: str):
+    @abc.abstractmethod
+    def _check_ip(self, ip_address: str) -> bool:
         """_check_ip checks if given IP is in set of allowed ones"""
         raise NotImplementedError
 
@@ -182,7 +207,7 @@ class BaseWebHookView(web.View):
         return None, False
 
     @abc.abstractmethod
-    async def post(self) -> None:
+    async def post(self) -> Any:
         """
         Process POST request with basic IP validation.
 
@@ -195,13 +220,12 @@ class BaseWebHookView(web.View):
 
         await self.handler_manager.process_event(update)
 
-    def _hash_validator(self, update: Union[
-        types.Notification, types.WebHook
-    ]) -> None:
+    def _hash_validator(self, update) -> None:
         """ Validating by hash of update """
 
     @property
-    def handler_manager(self) -> "HandlerManager":
+    def handler_manager(self) -> "Dispatcher":
         """ Return handler manager """
-        return self.request.app.get(
-            self.app_key_handler_manager)  # type: ignore
+        return self.request.app.get(  # type: ignore
+            self.app_key_handler_manager  # type: ignore
+        )  # type: ignore
