@@ -1,10 +1,7 @@
-import time
 from dataclasses import dataclass
 from typing import Union, Any, Optional
 
-from pydantic import BaseModel, Field
-
-from glQiwiApi.utils.basics import custom_load
+from pydantic import BaseModel, Field, validator
 
 DEFAULT_CACHE_TIME = 0
 
@@ -15,17 +12,18 @@ class Sum(BaseModel):
 
     """
     amount: Union[int, float, str]
-    currency: str
+    currency: Any
 
-    class Config:
-        """ Pydantic config """
-        json_loads = custom_load
+    @validator("currency", pre=True)
+    def humanize_pay_currency(cls, v):
+        from glQiwiApi.utils.currency_util import Currency
 
-        def __str__(self) -> str:
-            return f'Config class with loads={self.json_loads}'
-
-        def __repr__(self) -> str:
-            return self.__str__()
+        if not isinstance(v, int):
+            try:
+                v = int(v)
+            except ValueError:
+                return v
+        return Currency.get(str(v))
 
 
 class OptionalSum(BaseModel):
@@ -45,16 +43,6 @@ class Commission(BaseModel):
     qiwi_commission: Sum = Field("qwCommission")
     withdraw_to_enrollment_rate: int = Field(alias="withdrawToEnrollmentRate")
 
-    class Config:
-        """ Pydantic config """
-        json_loads = custom_load
-
-        def __str__(self) -> str:
-            return f'Config class with loads={self.json_loads}'
-
-        def __repr__(self) -> str:
-            return self.__str__()
-
 
 class Type(BaseModel):
     """
@@ -92,10 +80,7 @@ class Cached:
     """
     kwargs: Attributes
     response_data: Any
-    key: str
-    cache_to: str
-    method: str
-    cached_in: float = time.monotonic()
+    method: Optional[Any]
     status_code: Union[str, int, None] = None
 
 
