@@ -1,13 +1,16 @@
+import ipaddress
 from datetime import datetime
 from typing import Optional, List
 
-from pydantic import Field, BaseModel
+from pydantic import Field, validator
 
+from glQiwiApi.types.base import Base
 from glQiwiApi.types.basics import Sum
-from glQiwiApi.utils.basics import custom_load
+from glQiwiApi.types.qiwi_types.currency_parsed import CurrencyModel
+from glQiwiApi.utils.currency_util import Currency
 
 
-class PassInfo(BaseModel):
+class PassInfo(Base):
     """ object: PassInfo """
 
     last_pass_change: str = Field(alias="lastPassChange")
@@ -15,7 +18,7 @@ class PassInfo(BaseModel):
     password_used: bool = Field(alias="passwordUsed")
 
 
-class MobilePinInfo(BaseModel):
+class MobilePinInfo(Base):
     """ object: MobilePinInfo """
 
     last_mobile_pin_change: Optional[
@@ -25,14 +28,14 @@ class MobilePinInfo(BaseModel):
     next_mobile_pin_change: str = Field(alias="nextMobilePinChange")
 
 
-class PinInfo(BaseModel):
+class PinInfo(Base):
     """ object: PinInfo """
     pin_used: bool = Field(alias="pinUsed")
 
 
-class AuthInfo(BaseModel):
+class AuthInfo(Base):
     """ object: AuthInfo """
-    ip: str
+    ip: ipaddress.IPv4Address
     bound_email: Optional[str] = Field(alias="boundEmail", const=None)
     last_login_date: Optional[
         datetime
@@ -45,7 +48,7 @@ class AuthInfo(BaseModel):
     registration_date: datetime = Field(alias="registrationDate")
 
 
-class SmsNotification(BaseModel):
+class SmsNotification(Base):
     """ object: SmsNotification """
     price: Sum
     enabled: bool
@@ -53,14 +56,14 @@ class SmsNotification(BaseModel):
     end_date: Optional[datetime] = Field(alias="endDate", const=None)
 
 
-class IdentificationInfo(BaseModel):
+class IdentificationInfo(Base):
     """ object: IdentificationInfo """
     bank_alias: str = Field(alias="bankAlias")
     identification_level: str = Field(alias="identificationLevel")
     passport_expired: bool = Field(alias="passportExpired")
 
 
-class NickName(BaseModel):
+class NickName(Base):
     """ object: NickName """
     nickname: Optional[str] = None
     can_change: bool = Field(alias="canChange")
@@ -68,7 +71,7 @@ class NickName(BaseModel):
     description: str = ""
 
 
-class Feature(BaseModel):
+class Feature(Base):
     """ object: Feature """
     feature_id: int = Field(alias="featureId")
     feature_value: str = Field(alias="featureValue")
@@ -76,7 +79,7 @@ class Feature(BaseModel):
     end_date: str = Field(alias="endDate")
 
 
-class ContractInfo(BaseModel):
+class ContractInfo(Base):
     """ object: ContractInfo """
     blocked: bool = False
     contract_id: int = Field(alias="contractId")
@@ -87,12 +90,11 @@ class ContractInfo(BaseModel):
     sms_notification: SmsNotification = Field(alias="smsNotification")
     nickname: NickName
     features: Optional[List[Feature]] = None
-    blocked: bool
 
 
-class UserInfo(BaseModel):
+class UserInfo(Base):
     """ object: UserInfo """
-    default_pay_currency: str = Field(alias="defaultPayCurrency")
+    default_pay_currency: CurrencyModel = Field(alias="defaultPayCurrency")
     default_pay_source: Optional[
         int
     ] = Field(alias="defaultPaySource", const=None)
@@ -108,8 +110,14 @@ class UserInfo(BaseModel):
         bool
     ] = Field(alias="promoEnabled", const=None)
 
+    @validator("default_pay_currency", pre=True, check_fields=True)
+    def humanize_pay_currency(cls, v):
+        if not isinstance(v, int):
+            return v
+        return Currency.get(str(v))
 
-class QiwiAccountInfo(BaseModel):
+
+class QiwiAccountInfo(Base):
     """Информация об аккаунте"""
     auth_info: Optional[AuthInfo] = Field(alias="authInfo", const=None)
     contract_info: Optional[
@@ -117,16 +125,6 @@ class QiwiAccountInfo(BaseModel):
     ] = Field(alias="contractInfo", const=None)
     user_info: Optional[UserInfo] = Field(alias="userInfo", const=None)
 
-    class Config:
-        """ Pydantic config """
-        json_loads = custom_load
-
-        def __str__(self) -> str:
-            return f'Config class with loads={self.json_loads}'
-
-        def __repr__(self) -> str:
-            return self.__str__()
-
 
 __all__ = [
     'QiwiAccountInfo'
