@@ -1,14 +1,15 @@
 """Main model: Partner"""
 from typing import List, Optional
 
-from pydantic import BaseModel
+from glQiwiApi.types.base import Base
 
 
-class Partner(BaseModel):
+class Partner(Base):
     """ Base partner class """
     title: str
     id: int
 
     maps: Optional[List[str]] = None
 
+
 __all__ = ("Partner",)
