@@ -36,7 +36,14 @@ class InvalidToken(Exception):
 
 class InvalidData(Exception):
     """
-    Ошибка возникает, если были переданы или получены невалидные данные
+    Ошибка возникает если были переданы или получены невалидные данные
+
+    """
+
+
+class NoUpdatesToExecute(Exception):
+    """
+    Ошибка возбуждается если при полинге нет транзакций, чтобы обрабатывать
 
     """
 
@@ -49,7 +56,7 @@ class RequestError(Exception):
 
     def __init__(
             self,
-            message: str,
+            message: Optional[str],
             status_code: str,
             additional_info: Optional[str] = None,
             json_info: Optional[Union[Dict[str, Any], str]] = None
@@ -88,4 +95,5 @@ __all__ = (
     'InvalidCardNumber',
     'InvalidToken',
     'RequestError',
+    'NoUpdatesToExecute'
 )
